#ifndef GRAPHICS_H
#define GRAPHICS_H

#include <SDL.h>

struct Color
{
    Color(Uint8 _r = 0, Uint8 _g = 0, Uint8 _b = 0, Uint8 _a = 255);
    Color(Uint32 _argb);

    union
    {
       struct {Uint8 b,g,r,a;};
       Uint32   argb;
    };
};

class CGfx
{
public:
    CGfx();

    void    init(const char* title, int w, int h);
    void    init2D();
    void    quit();

    void    clearScreen(Color c);
    void    render();
    void    setPixel(int x, int y, Color c);
    Color   getPixel(int x, int y);
    void    line(int x0, int y0, int x1, int y1, Color c);
    void    rect(int x0, int y0, int x1, int y1, Color c);
    void    rectFill(int x0, int y0, int x1, int y1, Color c);

private:
    size_t  pixelPos2D(int x, int y);

    int             mWidth, mHeight;
    SDL_Window*     mWindow;
    SDL_Renderer*   mRenderer;
    SDL_Texture*    mTexture2D;
    Color*          mPixels2D;
};

extern CGfx gfx;

#endif // GRAPHICS_H
